/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                    TERCER GRADO DE SECUNDARIA (Excale 09)
/*
/*                        **** DIRECTORES CONTEXTO ****
/*
/*                     Ciclo escolar evaluado: 2007 - 2008
/*_____________________________________________________________________________
/*
/*
/*       PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE DIRECTORES DE CONTEXTO
/*                                EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale09_2008_Dir_Cuest.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale09_2008_Dir_Cuest.txt
/*         as como el archivo Excale09_2008_Dir_Cuest.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale09_2008_Dir_Cuest.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale09_2008_Dir_Cuest.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 16 DE MARZO DEL 2010
/*
/*  ****************************************************************************/


LIBNAME  INEE  "C:\***\";
FILENAME dir   "C:\***\Excale09_2008_Dir_Cuest.TXT";

PROC FORMAT;
     VALUE id_entF     1         = "Aguascalientes"
                       2         = "Baja California"
                       3         = "Baja California Sur"
                       4         = "Campeche"
                       5         = "Coahuila"
                       6         = "Colima"
                       7         = "Chiapas"
                       8         = "Chihuahua"
                       9         = "Distrito Federal"
                       10        = "Durango"
                       11        = "Guanajuato"
                       12        = "Guerrero"
                       13        = "Hidalgo"
                       14        = "Jalisco"
                       15        = "Mxico"
                       16        = "Michoacn"
                       17        = "Morelos"
                       18        = "Nayarit"
                       19        = "Nuevo Len"
                       20        = "Oaxaca"
                       21        = "Puebla"
                       22        = "Quertaro"
                       23        = "Quintana Roo"
                       24        = "San Luis Potos"
                       25        = "Sinaloa"
                       26        = "Sonora"
                       27        = "Tabasco"
                       28        = "Tamaulipas"
                       29        = "Tlaxcala"
                       30        = "Veracruz"
                       31        = "Yucatn"
                       32        = "Zacatecas";
     VALUE id_modF     6         = "General"
                       7         = "Tcnica"
                       8         = "Telesecundaria"
                       9         = "Privada";
     VALUE $modF       "GRAL"    = "General"
                       "TEC"     = "Tcnica"
                       "TV"      = "Telesecundaria"
                       "PRIV"    = "Privada";
     VALUE $mageb05F   "R"       = "Escuela rural"
                       "UA"      = "Escuela urbana de alta marginacin"
                       "UB"      = "Escuela urbana de baja marginacin"
                       "NA"      = "No aplica";
     VALUE ds001F      1         = "Hombre"
                       2         = "Mujer"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida" ;
     VALUE ds002F      1         = "Menos de 40"
                       2         = "Entre 40 y 49"
                       3         = "Entre 50 y 59"
                       4         = "60  ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida" ;
     VALUE ds3_6F      1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida" ;
     VALUE ds007F      1         = "Bachillerato o carrera tcnica"
                       2         = "Licenciatura"
                       3         = "Posgrado"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida" ;
     VALUE ds008F      0         = "Ninguna"
                       1         = "Cursos de nivelacin pedaggica"
                       2         = "Normal bsica sin licenciatura"
                       3         = "Normal superior o licenciatura en educacin"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida" ;
     VALUE ds009F      1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida" ;
     VALUE ds010F      2         = "S"
                       1         = "No"
                       0         = "No existe ese cargo en mi plantel"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida" ;
     VALUE ds011F      0         = "Ninguno"
                       1         = "1  menos"
                       2         = "Entre 2 y 5"
                       3         = "Entre 6 y 10"
                       4         = "Ms de 10"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida" ;
     VALUE ds012F      1         = "1  menos"
                       2         = "2  3"
                       3         = "4  ms"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida" ;
     VALUE ds013F      2         = "S, Carrera Magisterial"
                       1         = "S, algn programa propio de mi plantel"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida" ;
     VALUE ds014F      1         = "Inadecuadas"
                       2         = "Poco adecuadas"
                       3         = "Adecuadas"
                       4         = "Muy adecuadas"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida" ;
     VALUE ds15_23F    1         = "S"
                       0         = "No"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida" ;
     VALUE ds024F      1         = "Menos de 100"
                       2         = "Entre 100 y 200"
                       3         = "Entre 200 y 400"
                       4         = "Ms de 400"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida" ;
     VALUE ds025F      0         = "No existen computadoras para los alumnos"
                       1         = "Menos de 10"
                       2         = "Entre 11 y 30"
                       3         = "Entre 31 y 50"
                       4         = "Ms de 50"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida" ;
     VALUE ds26_31F    0         = "Nunca o casi nunca"
                       1         = "A veces"
                       2         = "Frecuentemente"
                       3         = "Muy frecuentemente"
                       8         = "Respuesta mltiple"
                       9         = "Respuesta omitida";
RUN;



DATA INEE.Excale09_2008_Dir_Cuest;
   LENGTH
       nacional           3
       escuela            4
       id_ent             3
       nom_ent            $19
       id_mod             3
       mod                $4
       mageb05            $2
       estrato            $7
       entest             $6
       id_instr           $12
       w_dir              8
       ds001              3
       ds002              3
       ds003              3
       ds004              3
       ds005              3
       ds006              3
       ds007              3
       ds008              3
       ds009              3
       ds010              3
       ds011              3
       ds012              3
       ds013              3
       ds014              3
       ds015              3
       ds016              3
       ds017              3
       ds018              3
       ds019              3
       ds020              3
       ds021              3
       ds022              3
       ds023              3
       ds024              3
       ds025              3
       ds026              3
       ds027              3
       ds028              3
       ds029              3
       ds030              3
       ds031              3
       wvarstrr           3
       w_fstr1            8
       w_fstr2            8
       w_fstr3            8
       w_fstr4            8
       w_fstr5            8
       w_fstr6            8
       w_fstr7            8
       w_fstr8            8
       w_fstr9            8
       w_fstr10           8
       w_fstr11           8
       w_fstr12           8
       w_fstr13           8
       w_fstr14           8
       w_fstr15           8
       w_fstr16           8
       w_fstr17           8
       w_fstr18           8
       w_fstr19           8
       w_fstr20           8
       w_fstr21           8
       w_fstr22           8
       w_fstr23           8
       w_fstr24           8
       w_fstr25           8
       w_fstr26           8
       w_fstr27           8
       w_fstr28           8
       w_fstr29           8
       w_fstr30           8
       w_fstr31           8
       w_fstr32           8
       w_fstr33           8
       w_fstr34           8
       w_fstr35           8
       w_fstr36           8
       w_fstr37           8
       w_fstr38           8
       w_fstr39           8
       w_fstr40           8
       w_fstr41           8
       w_fstr42           8
       w_fstr43           8
       w_fstr44           8
       w_fstr45           8
       w_fstr46           8
       w_fstr47           8
       w_fstr48           8
       w_fstr49           8
       w_fstr50           8
       w_fstr51           8
       w_fstr52           8
       w_fstr53           8
       w_fstr54           8
       w_fstr55           8
       w_fstr56           8
       w_fstr57           8
       w_fstr58           8
       w_fstr59           8
       w_fstr60           8
       w_fstr61           8
       w_fstr62           8
       w_fstr63           8
       w_fstr64           8
       w_fstr65           8
       w_fstr66           8
       w_fstr67           8
       w_fstr68           8
       w_fstr69           8
       w_fstr70           8
       w_fstr71           8
       w_fstr72           8
       w_fstr73           8
       w_fstr74           8
       w_fstr75           8
       w_fstr76           8
       w_fstr77           8
       w_fstr78           8
       w_fstr79           8
       w_fstr80           8
 ;

INFILE dir MISSOVER LINESIZE = 982;
   INPUT
       nacional          1 - 1
       escuela           2 - 5
       id_ent            6 - 7
       nom_ent           8 - 26
       id_mod           27 - 27
       mod              28 - 31
       mageb05          32 - 33
       estrato          34 - 40
       entest           41 - 46
       id_instr         47 - 58
       w_dir            59 - 69
       ds001            70 - 70
       ds002            71 - 71
       ds003            72 - 72
       ds004            73 - 73
       ds005            74 - 74
       ds006            75 - 75
       ds007            76 - 76
       ds008            77 - 77
       ds009            78 - 78
       ds010            79 - 79
       ds011            80 - 80
       ds012            81 - 81
       ds013            82 - 82
       ds014            83 - 83
       ds015            84 - 84
       ds016            85 - 85
       ds017            86 - 86
       ds018            87 - 87
       ds019            88 - 88
       ds020            89 - 89
       ds021            90 - 90
       ds022            91 - 91
       ds023            92 - 92
       ds024            93 - 93
       ds025            94 - 94
       ds026            95 - 95
       ds027            96 - 96
       ds028            97 - 97
       ds029            98 - 98
       ds030            99 - 99
       ds031           100 - 100
       wvarstrr        101 - 102
       w_fstr1         103 - 113
       w_fstr2         114 - 124
       w_fstr3         125 - 135
       w_fstr4         136 - 146
       w_fstr5         147 - 157
       w_fstr6         158 - 168
       w_fstr7         169 - 179
       w_fstr8         180 - 190
       w_fstr9         191 - 201
       w_fstr10        202 - 212
       w_fstr11        213 - 223
       w_fstr12        224 - 234
       w_fstr13        235 - 245
       w_fstr14        246 - 256
       w_fstr15        257 - 267
       w_fstr16        268 - 278
       w_fstr17        279 - 289
       w_fstr18        290 - 300
       w_fstr19        301 - 311
       w_fstr20        312 - 322
       w_fstr21        323 - 333
       w_fstr22        334 - 344
       w_fstr23        345 - 355
       w_fstr24        356 - 366
       w_fstr25        367 - 377
       w_fstr26        378 - 388
       w_fstr27        389 - 399
       w_fstr28        400 - 410
       w_fstr29        411 - 421
       w_fstr30        422 - 432
       w_fstr31        433 - 443
       w_fstr32        444 - 454
       w_fstr33        455 - 465
       w_fstr34        466 - 476
       w_fstr35        477 - 487
       w_fstr36        488 - 498
       w_fstr37        499 - 509
       w_fstr38        510 - 520
       w_fstr39        521 - 531
       w_fstr40        532 - 542
       w_fstr41        543 - 553
       w_fstr42        554 - 564
       w_fstr43        565 - 575
       w_fstr44        576 - 586
       w_fstr45        587 - 597
       w_fstr46        598 - 608
       w_fstr47        609 - 619
       w_fstr48        620 - 630
       w_fstr49        631 - 641
       w_fstr50        642 - 652
       w_fstr51        653 - 663
       w_fstr52        664 - 674
       w_fstr53        675 - 685
       w_fstr54        686 - 696
       w_fstr55        697 - 707
       w_fstr56        708 - 718
       w_fstr57        719 - 729
       w_fstr58        730 - 740
       w_fstr59        741 - 751
       w_fstr60        752 - 762
       w_fstr61        763 - 773
       w_fstr62        774 - 784
       w_fstr63        785 - 795
       w_fstr64        796 - 806
       w_fstr65        807 - 817
       w_fstr66        818 - 828
       w_fstr67        829 - 839
       w_fstr68        840 - 850
       w_fstr69        851 - 861
       w_fstr70        862 - 872
       w_fstr71        873 - 883
       w_fstr72        884 - 894
       w_fstr73        895 - 905
       w_fstr74        906 - 916
       w_fstr75        917 - 927
       w_fstr76        928 - 938
       w_fstr77        939 - 949
       w_fstr78        950 - 960
       w_fstr79        961 - 971
       w_fstr80        972 - 982
 ;

   LABEL
       nacional    = "Variable auxiliar para obtener promedios nacionales"
       escuela     = "Identificador de la escuela"
       id_ent      = "Entidad federativa (identificador numrico)"
       nom_ent     = "Entidad federativa"
       id_mod      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       mod         = "Estrato escolar o Modalidad educativa"
       mageb05     = "ndice de marginacin urbana 2005"
       estrato     = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD Y MARGINALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
       entest      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad-Densidad de poblacin)"
       id_instr    = "Identificador del cuestionario"
       w_dir       = "Peso muestral o ponderador del director"
       ds001       = "Es usted hombre o mujer?"
       ds002       = "Cuntos aos cumplidos tiene?"
       ds003       = "Trabaja otro turno como director o docente, en esta o en otra escuela?"
       ds004       = "Adems de ser director(a) tiene a su cargo algn grupo en esta escuela?"
       ds005       = "Adems de su trabajo en esta escuela, tiene otro empleo permanente por el cual reciba remuneracin?"
       ds006       = "Tiene usted clave de director(a) de su plantel?"
       ds007       = "Cul es su nivel mximo de estudios?"
       ds008       = "Cul es su formacin especfica como docente?"
       ds009       = "Antes de ser director(a) se desempeo como subdirector(a)?"
       ds010       = "Antes de ser director(a) se desempeo como coordinador(a) acadmico(a)?"
       ds011       = "Antes de ser director(a), cuntos aos se desempeo como docente?"
       ds012       = "Cuntos cursos de capacitacin o actualizacin (de al menos 20 horas) que hayan aportado algo a su labor directiva, tom en los ltimos 3 aos?"
       ds013       = "Est usted incorporado a algn programa de estmulos para la actividad docente o directiva?"
       ds014       = "En su opinin cmo son las condiciones fsicas generales de su plantel?"
       ds015       = "En su plantel existe sala de maestros?"
       ds016       = "En su plantel existen instalaciones deportivas?"
       ds017       = "En su plantel existe algn auditorio?"
       ds018       = "En su plantel existen laboratorios?"
       ds019       = "En su plantel existe biblioteca?"
       ds020       = "En su plantel existen instalaciones adecuadas para alumnos con capacidades diferentes?"
       ds021       = "Su plantel cuenta con drenaje?"
       ds022       = "Su plantel cuenta con lnea telefnica?"
       ds023       = "Su plantel cuenta con conexin a Internet?"
       ds024       = "Cuntos libros hay en la biblioteca de su escuela, sin contar los de las bibliotecas de aula?"
       ds025       = "Cuntas computadoras en buen estado tiene su plantel para uso de los estudiantes?"
       ds026       = "Existe una buena interaccin entre sus docentes?"
       ds027       = "Existe una buena interaccin entre sus alumnos?"
       ds028       = "Existe una buena interaccin entre sus docentes y los alumnos?"
       ds029       = "Participan los padres de familia en las actividades de Escuela para Padres que organiza su plantel?"
       ds030       = "Los padres de familia participan en las reuniones acadmicas que organiza su plantel?"
       ds031       = "Se considera la opinin de los padres de familia en la toma de decisiones acadmicas de su plantel?"
       wvarstrr    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       w_fstr1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       w_fstr80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
 ;

   FORMAT
        nacional       1.
        escuela        4.
        id_ent         id_entF.
        nom_ent        $char19.
        id_mod         id_modF.
        mod            $modF.
        mageb05        mageb05F.
        estrato        $char7.
        entest         $char6.
        id_instr       $char12.
        ds001          ds001F.
        ds002          ds002F.
        ds003          ds3_6F.
        ds004          ds3_6F.
        ds005          ds3_6F.
        ds006          ds3_6F.
        ds007          ds007F.
        ds008          ds008F.
        ds009          ds009F.
        ds010          ds010F.
        ds011          ds011F.
        ds012          ds012F.
        ds013          ds013F.
        ds014          ds014F.
        ds015          ds15_23F.
        ds016          ds15_23F.
        ds017          ds15_23F.
        ds018          ds15_23F.
        ds019          ds15_23F.
        ds020          ds15_23F.
        ds021          ds15_23F.
        ds022          ds15_23F.
        ds023          ds15_23F.
        ds024          ds024F.
        ds025          ds025F.
        ds026          ds26_31F.
        ds027          ds26_31F.
        ds028          ds26_31F.
        ds029          ds26_31F.
        ds030          ds26_31F.
        ds031          ds26_31F.
 ;


/**************************************************************************
/*  Definicin de valores perdidos
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   ARRAY perdidos1(31)
                   ds001 ds002 ds003 ds004 ds005 ds006 ds007 ds008
                   ds009 ds010 ds011 ds012 ds013 ds014 ds015 ds016
                   ds017 ds018 ds019 ds020 ds021 ds022 ds023 ds024
                   ds025 ds026 ds027 ds028 ds029 ds030 ds031;
   DO  i=1 TO 31;
          IF perdidos1{i} = 8   THEN  perdidos1{i} = .M;
          IF perdidos1{i} = 9   THEN  perdidos1{i} = .S;
   END;

   drop i;
RUN;



